@@ -178,12 +178,18 @@ Performs connect operation.
 
 This method calls L<Sys#connect> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and $sockaddr.
 
-If connect operation need to be performed again for IO wait, L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+If connect operation need to be performed again for IO wait, L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout"> field.
+
+And when the current goroutine is returned, this method retries connect operation.
+
+If timeout occurs, an exception is thrown set C<eval_error_id> to the basic type ID of the L<Go::Error::IOTimeout|SPVM::Go::Error::IOTimeout> class.
 
 Exceptions:
 
 Exceptions thrown by L<Sys#connect> method could be thrown.
 
+Exceptions thrown by L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method could be thrown.
+
 =head2 bind
 
 C<protected method bind : void ($sockaddr : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>);>
@@ -218,7 +224,11 @@ The type of the returned object is the type of this instance.
 
 This method calls L<Sys#accept|SPVM::Sys|/"accept"> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and $peer_ref.
 
-If accept operation need to be performed again for IO wait, L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+If accept operation need to be performed again for IO wait, L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout"> field.
+
+And when the current goroutine is returned, this method retries accept operation.
+
+If timeout occurs, an exception is thrown set C<eval_error_id> to the basic type ID of the L<Go::Error::IOTimeout|SPVM::Go::Error::IOTimeout> class.
 
 $peer_ref at index 0 is set to a client socket address if specified.
 
@@ -226,6 +236,8 @@ Exceptions:
 
 Exceptions thrown by L<Sys#accept|SPVM::Sys|/"accept"> method could be thrown.
 
+Exceptions thrown by L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method could be thrown.
+
 =head2 shutdown
 
 C<method shutdown : void ($how : int);>
@@ -268,13 +280,19 @@ C<method recvfrom : int ($buffer : mutable string, $length : int, $flags : int,
 
 Performs recvfrom operation and returns read length.
 
-This method calls L<Sys#recvfrom> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $buffer, $length, $flags, $from_ref, $offset, and returns its return value.
+This method calls L<Sys#recvfrom|SPVM::Sys/"recvfrom"> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $buffer, $length, $flags, $from_ref, $offset, and returns its return value.
 
-If recvfrom operation need to be performed again for IO wait, L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+If recvfrom operation need to be performed again for IO wait, L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout"> field.
+
+And when the current goroutine is returned, this method retries recvfrom operation.
+
+If timeout occurs, an exception is thrown set C<eval_error_id> to the basic type ID of the L<Go::Error::IOTimeout|SPVM::Go::Error::IOTimeout> class.
 
 Exceptions:
 
-Exceptions thrown by L<Sys#recvfrom> method could be thrown.
+Exceptions thrown by L<Sys#recvfrom|SPVM::Sys/"recvfrom"> method could be thrown.
+
+Exceptions thrown by L<Go#gosched_io_read|SPVM::Go/"gosched_io_read"> method could be thrown.
 
 =head2 sendto
 
@@ -282,13 +300,19 @@ C<method sendto : int ($buffer : string, $flags : int, $to : L<Sys::Socket::Sock
 
 Performs sendto operation and returns write length.
 
-This method calls L<Sys#sendto> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $buffer, $flags, $to, $length, $offset, and returns its return value.
+This method calls L<Sys#sendto|SPVM::Sys/"sendto"> method given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field, $buffer, $flags, $to, $length, $offset, and returns its return value.
 
-If sendto operation need to be performed again for IO wait, L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout> field.
+If sendto operation need to be performed again for IO wait, L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method is called given the value of L<IO::Handle#FD|SPVM::IO::Handle/"FD"> field and the value of L</"Timeout"> field.
+
+And when the current goroutine is returned, this method retries sendto operation.
+
+If timeout occurs, an exception is thrown set C<eval_error_id> to the basic type ID of the L<Go::Error::IOTimeout|SPVM::Go::Error::IOTimeout> class.
 
 Exceptions:
 
-Exceptions thrown by L<Sys#sendto> method could be thrown.
+Exceptions thrown by L<Sys#sendto|SPVM::Sys/"sendto"> method could be thrown.
+
+Exceptions thrown by L<Go#gosched_io_write|SPVM::Go/"gosched_io_write"> method could be thrown.
 
 =head2 recv
 
